@@ -473,19 +473,17 @@ int fluxconf(int argc, char **argv, char standalone)
     gtk_box_pack_start(GTK_BOX(vbox1), s[13].wid, FALSE, FALSE, 0);
     items = NULL;
 
-    items = g_list_append(items, "CascadePlacement");
     items = g_list_append(items, "ColSmartPlacement");
     items = g_list_append(items, "RowSmartPlacement");
+    items = g_list_append(items, "CascadePlacement");
+    items = g_list_append(items, "UnderMousePlacement");
     s[14].wid =
         newchoice(_("Window placement"), s[14].value, items, _("Change the way windows are placed"),
                   tip);
     gtk_box_pack_start(GTK_BOX(vbox1), s[14].wid, FALSE, FALSE, 0);
     items = NULL;
 
-    items = g_list_append(items, "AutoRaiseSloppyFocus");
-    items = g_list_append(items, "SloppyFocus");
-    items = g_list_append(items, "AutoRaiseSemiSloppyFocus");
-    items = g_list_append(items, "SemiSloppyFocus");
+    items = g_list_append(items, "MouseFocus");
     items = g_list_append(items, "ClickToFocus");
     s[15].wid = newchoice(_("Focus model"), s[15].value, items, _("Change the focus method"), tip);
     gtk_box_pack_start(GTK_BOX(vbox1), s[15].wid, FALSE, FALSE, 0);
