@@ -104,7 +104,7 @@ int fluxkeys(int argc, char **argv, char standalone)
         checkptr(config);
         config[i - 1] = (char *) malloc(10 + strlen(buf) * sizeof(char));
         checkptr(config[i - 1]);
-        if (strlen(buf) > 10 && buf[0] != '#') {
+        if (strlen(buf) > 10 && buf[0] != '!') {
             strcpy(config[i - 1], buf);
             i++;
         }
@@ -178,11 +178,11 @@ int fluxkeys(int argc, char **argv, char standalone)
         if (!strcasecmp(tmp, "ExecCommand")) {
             for (x = strlen(tmp); buf[x] < 33; x++);
             boxes[i] =
-                newkey(modifiers & 1, modifiers & 2, modifiers & 4, modifiers & 8, actlist, tmp,
+                newkey(modifiers, actlist, tmp,
                        touche, buf + x);
         } else
             boxes[i] =
-                newkey(modifiers & 1, modifiers & 2, modifiers & 4, modifiers & 8, actlist, buf,
+                newkey(modifiers, actlist, buf,
                        touche, "");
         gtk_box_pack_start(GTK_BOX(mainvbox), boxes[i], FALSE, FALSE, 0);
     }
@@ -205,24 +205,28 @@ int fluxkeys(int argc, char **argv, char standalone)
 void delkey(GtkButton *button, gpointer data)
 {
     button = NULL; /* FIXME without this gcc hangs */
-    nblignes--;
+    /* manu@20080811:
+     *   Don't decrement line count, we'll skip NULL'ed items. */
+    /* nblignes--; */
     gtk_widget_destroy(data);
 }
 
-GtkWidget *newkey(int Ctrl, int Alt, int Shift, int Win, GList * liste, char *value, char *touche, char *execcmd)
+GtkWidget *newkey(int modifiers, GList * liste, char *value, char *touche, char *execcmd)
 {
-    GtkWidget *hbox, *m1, *m2, *m3, *m4, *combo, *entry, *key, *del;
+    GtkWidget *hbox, *m1, *m2, *m3, *m4, *m5, *combo, *entry, *key, *del;
 
     hbox = gtk_hbox_new(FALSE, 1);
     m1 = gtk_toggle_button_new_with_label("Control");
     m2 = gtk_toggle_button_new_with_label("Mod1");
     m3 = gtk_toggle_button_new_with_label("Shift");
     m4 = gtk_toggle_button_new_with_label("Mod4");
+    m5 = gtk_toggle_button_new_with_label("OnDesktop");
 
-    gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(m1), Ctrl);
-    gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(m2), Alt);
-    gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(m3), Shift);
-    gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(m4), Win);
+    gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(m1), modifiers & MOD_CTRL);
+    gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(m2), modifiers & MOD_ALT);
+    gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(m3), modifiers & MOD_SHIFT);
+    gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(m4), modifiers & MOD_WIN);
+    gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(m5), modifiers & MOD_ONDESKTOP);
 
     combo = gtk_combo_new();
     gtk_combo_set_popdown_strings(GTK_COMBO(combo), liste);
@@ -244,6 +248,7 @@ GtkWidget *newkey(int Ctrl, int Alt, int Shift, int Win, GList * liste, char *va
     gtk_box_pack_start(GTK_BOX(hbox), m2, FALSE, FALSE, 1);
     gtk_box_pack_start(GTK_BOX(hbox), m3, FALSE, FALSE, 1);
     gtk_box_pack_start(GTK_BOX(hbox), m4, FALSE, FALSE, 1);
+    gtk_box_pack_start(GTK_BOX(hbox), m5, FALSE, FALSE, 1);
     gtk_box_pack_start(GTK_BOX(hbox), key, FALSE, FALSE, 1);
     gtk_box_pack_start(GTK_BOX(hbox), combo, FALSE, FALSE, 1);
     gtk_box_pack_start(GTK_BOX(hbox), entry, TRUE, TRUE, 1);
@@ -294,6 +299,7 @@ void savekeys(GtkButton *button, GtkBox ** boites) /* FIXME GtkButton *button is
             for (n = strlen("session.keyFile:") + 1; buf[n] < 33; n++);
             buf[strlen(buf) - 1] = 0;
             strncpy(initpath, buf + n, MAXPATHLEN);
+	    break;
         }
     }
     fclose(file);
@@ -341,39 +347,49 @@ void savekeys(GtkButton *button, GtkBox ** boites) /* FIXME GtkButton *button is
      * execact=(char*)malloc(EXELEN*sizeof(char));
      */
 #ifndef DEBUG
-    fprintf(file, _("# File generated by FluxConf\n"));
+    fprintf(file, _("!Generated by fluxkeys\n"));
 #else
-    g_print(_("# File generated by FluxConf\n"));
+    g_print(_("!Generated by fluxkeys\n"));
 #endif
     for (x = 0; x < nblignes + 1; x++) {
-        mod = 0;
+        mod = MOD_NONE;
+	if (NULL == boites[x]->children) {
+	    /* manu@20080811: 
+	     *   An element in the middle of the list has been removed. 
+	     *   Ignore it and process the next one. */
+	    continue;
+	}
         child = boites[x]->children->data;
         wid = child->widget;
         if (gtk_toggle_button_get_active(GTK_TOGGLE_BUTTON(wid)))
-            mod |= 1;
+            mod |= MOD_CTRL;
         child = boites[x]->children->next->data;
         wid = child->widget;
         if (gtk_toggle_button_get_active(GTK_TOGGLE_BUTTON(wid)))
-            mod |= 2;
+            mod |= MOD_ALT;
         child = boites[x]->children->next->next->data;
         wid = child->widget;
         if (gtk_toggle_button_get_active(GTK_TOGGLE_BUTTON(wid)))
-            mod |= 4;
+            mod |= MOD_SHIFT;
         child = boites[x]->children->next->next->next->data;
         wid = child->widget;
         if (gtk_toggle_button_get_active(GTK_TOGGLE_BUTTON(wid)))
-            mod |= 8;
+            mod |= MOD_WIN;
+        child = boites[x]->children->next->next->next->next->data;
+        wid = child->widget;
+        if (gtk_toggle_button_get_active(GTK_TOGGLE_BUTTON(wid)))
+            mod |= MOD_ONDESKTOP;
         /*
          * all modifiers are ok 
          */
-        child = boites[x]->children->next->next->next->next->data;
-        wid = child->widget;
-        key = gtk_entry_get_text(GTK_ENTRY(wid));   /* get the key entry */
         child = boites[x]->children->next->next->next->next->next->data;
         wid = child->widget;
-        action = gtk_entry_get_text(GTK_ENTRY(GTK_COMBO(wid)->entry));  /* get the action entry */
+        key = gtk_entry_get_text(GTK_ENTRY(wid));   /* get the key entry */
         child = boites[x]->children->next->next->next->next->next->next->data;
         wid = child->widget;
+        action = gtk_entry_get_text(GTK_ENTRY(GTK_COMBO(wid)->entry));  /* get the action entry */
+        child = boites[x]->children->next->next->next->next->next->next->next->data;
+        wid = child->widget;
         execact = gtk_entry_get_text(GTK_ENTRY(wid));   /* get the exec action entry */
         if (strlen(key)) {
             if (!mod)
@@ -383,30 +399,36 @@ void savekeys(GtkButton *button, GtkBox ** boites) /* FIXME GtkButton *button is
                 g_print("None ");
 #endif
             else {
-                if (mod & 1)
+                if (mod & MOD_CTRL)
 #ifndef DEBUG
                     fprintf(file, "Control ");
 #else
                     g_print("Control ");
 #endif
-                if (mod & 2)
+                if (mod & MOD_ALT)
 #ifndef DEBUG
                     fprintf(file, "Mod1 ");
 #else
                     g_print("Mod1 ");
 #endif
-                if (mod & 4)
+                if (mod & MOD_SHIFT)
 #ifndef DEBUG
                     fprintf(file, "Shift ");
 #else
                     g_print("Shift ");
 #endif
 
-                if (mod & 8)
+                if (mod & MOD_WIN)
 #ifndef DEBUG
                     fprintf(file, "Mod4 ");
 #else
                     g_print("Mod4 ");
+#endif
+                if (mod & MOD_ONDESKTOP)
+#ifndef DEBUG
+                    fprintf(file, "OnDesktop ");
+#else
+                    g_print("OnDesktop ");
 #endif
             }
 #ifndef DEBUG
@@ -430,12 +452,13 @@ void savekeys(GtkButton *button, GtkBox ** boites) /* FIXME GtkButton *button is
 
 
 /* void addkey(GtkButton * but, GtkWidget ** boites) */
-void addkey(GtkWidget ** boites)
+void addkey(GtkButton * button, GtkWidget ** boites)
 {
+    button = button;
     if (nblignes > MAXKEYCOUNT - 2)
         return;
     nblignes++;
-    boites[nblignes] = newkey(FALSE, FALSE, FALSE, FALSE, actlist, "", "", "");
+    boites[nblignes] = newkey(MOD_NONE, actlist, "", "", "");
     gtk_box_pack_start(GTK_BOX(mainvbox), boites[nblignes], FALSE, FALSE, 0);
     gtk_widget_show_all(boites[nblignes]);
 }
@@ -478,13 +501,15 @@ char *getthings(char *word, int *mod, char *thekey)
         seek += x;
         seek += strlen(rest);   /* FIXME?: isn't there a way to avoid repeating this strlen() call n times ? */
         if (!strcasecmp(rest, "Control"))
-            *mod |= 1;
+            *mod |= MOD_CTRL;
         else if (!strcasecmp(rest, "Mod1"))
-            *mod |= 2;
+            *mod |= MOD_ALT;
         else if (!strcasecmp(rest, "Shift"))
-            *mod |= 4;
+            *mod |= MOD_SHIFT;
         else if (!strcasecmp(rest, "Mod4"))
-            *mod |= 8;
+            *mod |= MOD_WIN;
+	else if (!strcasecmp(rest, "OnDesktop"))
+	    *mod |= MOD_ONDESKTOP;
         else if (!strcasecmp(rest, "None"));
         else if (seek < max) {
             strncpy(thekey, rest, strlen(rest));    /* FIXME: check boundaries. thekey can contain at most 10 bytes */
