@@ -37,6 +37,14 @@ Please, run 'fluxconf' to change the location of this file to one you can write.
 
 #define STANDALONE 1
 
+
+#define MOD_NONE	0
+#define MOD_CTRL	1
+#define MOD_ALT		2
+#define MOD_SHIFT	4
+#define MOD_WIN		8
+#define MOD_ONDESKTOP	16
+
 /* enums */
 #ifdef GTK2
 enum {
