@@ -24,8 +24,9 @@ char * getthings(char * word, int * mod, char * thekey);
 char * firstword(char * word, int * offset);
 
 void savekeys(GtkButton *button, GtkBox ** boxes);
-void addkey(GtkWidget ** boxes);
-GtkWidget * newkey(int Ctrl, int Alt, int Shift, int Win, 
+void addkey(GtkButton * button, GtkWidget ** boxes);
+/* void addkey(GtkWidget ** boxes); */
+GtkWidget * newkey(int modifiers, 
                     GList * liste, char *value, char *touche, char *execcmd
                     );
 
